#
# spec file for package nvim-lspconfig
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvim-lspconfig
Version:        1.7.0
Release:        1.1
Summary:        Quickstart configs for Nvim LSP
License:        Apache-2.0
URL:            https://github.com/neovim/nvim-lspconfig
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  neovim
Requires:       neovim
BuildArch:      noarch

%description
default Nvim LSP client configurations for various LSP servers

%package doc
Summary:        Documentation for %{name}

%description doc
%{summary}.

%prep
%autosetup
%fdupes -s doc

%build
nvim -u NONE -i NONE -e --headless -c "helptags doc" -c quit

%install
install -d %{buildroot}%{_datadir}/nvim/runtime/
cp -r lua plugin %{buildroot}%{_datadir}/nvim/runtime/

%files
%license LICENSE.md
%doc CONTRIBUTING.md README.md
%{_datadir}/nvim/runtime/lua/lspconfig
%{_datadir}/nvim/runtime/lua/lspconfig.lua
%{_datadir}/nvim/runtime/plugin/lspconfig.lua

%files doc
%doc doc

%changelog
* Mon Feb 24 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.7.0:
  * docs: fix broken documentation link in rust_analyzer config
  * feat(harper-ls): added new languages and updated links
  * feat: dts-lsp
  * fix(health.lua): increased version check cmd timeout
  * feat: add wasm-language-tools
  * docs: don't skip VIMRUNTIME in lua lsp if ~/.config/nvim/.luarc.json exists
  * docs(atlas): add treesitter instructions
  * feat(oxc_language_server): add OxcFixAll command
  * fix(angularls): trim leading characters from version
  * fix(nushell): root_dir should avoid returning nil
  * docs: heading levels for veridian fixed
  * feat(r_language_server): add quarto filetype
  * fix(lua_ls): return longest root path
  * Add config for turbo-language-server
  * feat: add air lsp
* Mon Feb 17 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.6.0:
  * revert: "refactor!: make available_servers function private"
  * fix(angularls): set Angular core version for backwards compatibility
  * fix(angularls): handle nil while checking angular core version
- update to 1.5.0:
  * fix(gh_actions_ls): Fix incorrect rootdir resolution
  * fix: remove validation from configs.lua
  * fix(astro,volar): correct 'typescript/lib' path for TypeScript LSP
  * feat: oxc-language-server
- update to 1.4.0:
  * fix(powershell_es): add root pattern
  * fix(clojure_lsp): adds single_file_support for clojure
  * Feat: add lua 3rd party language servers
  * feat: gh-actions-language-server
  * feat(gh_actions_ls): use root_dir to decide whether to attach
  * feat: add typst to the list of languages harper supports
  * feat: Alloy language server
  * Improve alloy_ls docs
  * feat(asm_lsp): add NASM config support and single_file support
  * refactor: comment util.path.is_descendant to prepare deperecation in future
  * refactor!: make available_servers function private
  * docs: Use a maintained fork for kubernetes-json-schema in the example
  * build: add -q flag to luacheck
  * build: remove docgen.sh
  * refactor: silence luals warnings
  * docs: fix typo
  * fix: fix incorrect root finding
* Sun Jan  5 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.3.0:
  * refactor: deprecate util.path.join
  * refactor: deprecate util.path.path_separator
  * refactor: silence luals warnings
  * refactor: deprecate util.path.iterate_parents
  * feat: add server configuration for autohotkey_lsp (init)
  * refactor!: remove public interface of util.path.traverse_parents
  * fix(mdx-analyzer): Duplicate node_modules folder causing errors, and
    filetypes option
  * fix: add build.gradle.kts for java language server
  * feat: cue language server
  * feat(ccls): add CclsSwitchSourceHeader
  * fix(ccls): typo on request method
  * refactor(clangd): imporve switchsourceheader handler
  * fix(clangd): fix switchSourceHeader detection
  * docs(ruby_lsp): Remove instructions for adding ruby-lsp to Gemfile
  * feat: Update Harper's Supported Languages
  * feat: atlas language server
  * fix(msbuild): more root patterns
* Mon Dec 30 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.2.0:
  * refactor: deprecate util.find_package_json_ancestor
  * Fix for vim.fs.find regression not returning parent directory
  * refactor: deprecate util.find_git_ancestor
  * refactor!: remove util.path.escape_wildcards
  * refactor!: remove util.path.is_absolute
  * fix ruff and ruff_lsp returning a function from root pattern
  * feat(msbuild): config instruction for filetypes
  * refactor: fix luals warnings
* Sat Dec 14 2024 Richard Rahl <rrahl0@opensuse.org>
- initial packaging
